Crate minigrepx719

Crate minigrepx719 

Mini-grep

Mini-grep is a searching tool to print texts that match the contents of the specified file at the file path

Structs

Config

Functions

run
Runs the Searching Functionality
search
search_case_insensitive